// src/composables/useTextToSpeech.ts
import { onUnmounted } from 'vue';

export default function useTextToSpeech() {
  const speech = new SpeechSynthesisUtterance();
  let isPlaying = false;

  // 过滤HTML标签
  const stripHtml = (html: string): string => {
    const doc = new DOMParser().parseFromString(html, 'text/html');
    return doc.body.textContent || '';
  };

  // 播放文本
  const speak = (text: string) => {
    stop(); // 停止当前播放

    const cleanText = stripHtml(text).trim();
    if (!cleanText) {
      console.warn('No valid text to speak');
      return;
    }

    speech.text = cleanText;
    isPlaying = true;

    speech.onend = () => {
      isPlaying = false;
    };

    speech.onerror = (event) => {
      console.error('Speech error:', event);
      isPlaying = false;
    };

    window.speechSynthesis.speak(speech);
  };

  // 停止播放
  const stop = () => {
    if (isPlaying) {
      window.speechSynthesis.cancel();
      isPlaying = false;
    }
  };

  // 组件卸载时自动停止
  onUnmounted(() => {
    stop();
  });

  return {
    speak,
    stop
  };
}