import {defineConfig, loadEnv} from 'vite'
import vue from '@vitejs/plugin-vue'
import topLevelAwait from 'vite-plugin-top-level-await'
import { resolve } from 'path'
import viteCompression from 'vite-plugin-compression';//Gzip
import { visualizer } from "rollup-plugin-visualizer";
import { createSvgIconsPlugin } from 'vite-plugin-svg-icons' // 【svg-icons相关】
import VitePluginHtmlEnv from 'vite-plugin-html-env'

const time = new Date().getTime()
export default defineConfig(({mode, command}) => {
  const env = loadEnv(mode, process.cwd())
  const { VITE_BASE } = env
  return {
    define: {
      'process.env': process.env
    },
    plugins: [
      vue(),
      viteCompression(),
      VitePluginHtmlEnv(),
      visualizer(),
      createSvgIconsPlugin({
        // 指定需要缓存的图标文件夹
        iconDirs: [resolve(process.cwd(), 'src/assets/svg')],
        // 指定symbolId格式
        symbolId: 'icon-[dir]-[name]',
        // svgoOptions: {
        //   plugins: [
        //     {
        //       name: 'removeAttrs',
        //       params: {
        //         attrs: ['class', 'data-name', 'fill', 'stroke']
        //       }
        //     }
        //   ]
        // }
      }),
      topLevelAwait({
        promiseExportName: '__tla',
        promiseImportName: i => `__tla_${i}`
      })
    ],
    base: '/' + VITE_BASE + '/',
    resolve: {
      alias: {
        '@': resolve(__dirname, 'src'),
      },
    },
    server: {
      port: 9616,
      host: '0.0.0.0',
      open: true,
      strictPort: false,
      proxy: {
        '/dify-api': {
          target: 'http://1.95.78.201/',
          changeOrigin: true,
          rewrite: (path) => {
            return path.replace(/^\/dify-api/, '')
          }
        },
        '/cms-api': {
          target: 'http://192.168.5.98:8090/',
          // target: 'http://192.168.4.12:8090/',
          changeOrigin: true,
          rewrite: (path) => {
            return path.replace(/^\/cms-api/, '')
          }
        },
      }
    },
    build: {
      target: 'esnext',
      outDir: "smart-ask-answer-web",
      rollupOptions: {//分包优化
        output: {
          manualChunks(id) {
            if (id.includes('node_modules')) {
              return time + id.toString().split('node_modules/')[1].split('/')[0].toString();
            } else {
              return time + id.toString();
            }
          }
        }
      }
    },
    publicDir: 'src/out',
    optimizeDeps: {
      include: []
    }
  } as any
})
